/*
 * Copyright 2007 scala-tools.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 */
package scala.maven;

import java.io.File;
import java.io.IOException;
import java.util.List;

/**
 * Abstract parent of all Scala Mojo
 */
public abstract class ScalaCompilerSupport extends ScalaMojoSupport {

    abstract protected File getOutputDir() throws Exception;
    abstract protected File getSourceDir() throws Exception;
    abstract protected List<String> getClasspathElements() throws Exception;

    @Override
    protected final void doExecute() throws Exception {
        File outputDir = getOutputDir();
        if (!outputDir.exists()) {
            outputDir.mkdirs();
        }

        File sourceDir = getSourceDir();
        try {
            sourceDir = sourceDir.getCanonicalFile();
        } catch (IOException exc) {
            sourceDir = sourceDir.getAbsoluteFile();
        }
        if (!sourceDir.exists()) {
            return;
        }
        String[] sourceFiles = JavaCommand.findFiles(sourceDir, "**/*.scala");
        if (sourceFiles.length == 0) {
            getLog().warn("No source files found.");
            return;
        }

        JavaCommand jcmd = getScalaCommand();
        jcmd.addArgs("-classpath", JavaCommand.toMultiPath(getClasspathElements()));
        jcmd.addArgs("-d", outputDir.getAbsolutePath());
        jcmd.addArgs("-sourcepath", sourceDir.getAbsolutePath());
        for (String x : sourceFiles) {
            jcmd.addArgs(sourceDir + File.separator + x);
        }
        jcmd.run(displayCmd);
    }
}
